@@ -72,7 +72,7 @@ void MarkdownInterface::createAction(KActionCollection *ac)
 
     mPopupMenuAction = new QAction(i18n("Markdown Action"), this);
 
-    QMenu *mardownMenu = new QMenu;
+    QMenu *mardownMenu = new QMenu(parentWidget());
     mPopupMenuAction->setMenu(mardownMenu);
     mPopupMenuAction->setEnabled(false);
     QMenu *titleMenu = new QMenu(i18n("Add Title"), mardownMenu);
