@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,7 +22,7 @@
 #include <AkonadiCore/itemmodifyjob.h>
 #include <kcontacts/addressee.h>
 #include <KLocalizedString>
-#include <kmessagebox.h>
+#include <KMessageBox>
 
 UpdateContactJob::UpdateContactJob(const QString &email, const KContacts::Addressee &contact, QWidget *parentWidget, QObject *parent)
     : KJob(parent)
