@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,7 +21,8 @@
 #include "fancyheaderstyleplugin.h"
 #include "fancyheaderstyle.h"
 #include "messageviewer/richheaderstrategy.h"
-#include <kpluginfactory.h>
+#include <KPluginFactory>
+#include <KLocalizedString>
 #include <QApplication>
 
 using namespace MessageViewer;
@@ -197,4 +198,11 @@ QString FancyHeaderStylePlugin::extraCommonCss(const QString &headerFont) const
     return val;
 }
 
+QString MessageViewer::FancyHeaderStylePlugin::attachmentHtml() const
+{
+    return QStringLiteral("<div style=\"float:left;\">%1&nbsp;</div>").arg(i18n("Attachments:"));
+}
+
 #include "fancyheaderstyleplugin.moc"
+
+
